selectiontools.LogicalTie
=========================

.. abjad-lineage:: abjad.tools.selectiontools.LogicalTie.LogicalTie

.. autoclass:: abjad.tools.selectiontools.LogicalTie.LogicalTie

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.all_leaves_are_in_same_parent
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.get_duration
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.get_spanners
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.get_timespan
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.group_by
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.head
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.is_pitched
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.is_trivial
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.leaves
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.leaves_grouped_by_immediate_parents
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.partition_by_durations
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.partition_by_durations_exactly
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.partition_by_durations_not_greater_than
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.partition_by_durations_not_less_than
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.tail
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.tie_spanner
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.to_tuplet
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.written_duration
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__add__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__contains__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__eq__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__format__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__getitem__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__hash__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__illustrate__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__len__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__ne__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__radd__
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie.__repr__

Bases
-----

- :py:class:`selectiontools.ContiguousSelection <abjad.tools.selectiontools.ContiguousSelection.ContiguousSelection>`

- :py:class:`selectiontools.Selection <abjad.tools.selectiontools.Selection.Selection>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.all_leaves_are_in_same_parent
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.head
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.is_pitched
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.is_trivial
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.leaves
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.leaves_grouped_by_immediate_parents
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.tail
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.tie_spanner
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.LogicalTie.LogicalTie.written_duration
   :noindex:

Methods
-------

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.get_duration
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.get_spanners
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.get_timespan
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.group_by
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.partition_by_durations
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.partition_by_durations_exactly
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.partition_by_durations_not_greater_than
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.partition_by_durations_not_less_than
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.to_tuplet
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__add__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__contains__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__eq__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__format__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__getitem__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__hash__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__illustrate__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__len__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__ne__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__radd__
   :noindex:

.. automethod:: abjad.tools.selectiontools.LogicalTie.LogicalTie.__repr__
   :noindex:
